@@ -2,13 +2,13 @@
 #this repository contains the full copyright notices and license terms.
 from trytond.model import Model, fields
 from trytond.pyson import Eval
-import luhn
+from . import luhn
 
 
 class Party(Model):
     _name = 'party.party'
 
-    siren = fields.Char('SIREN', select=1, states={
+    siren = fields.Char('SIREN', select=True, states={
             'readonly': ~Eval('active', True),
             }, size=9, depends=['active'])
 
@@ -26,8 +26,10 @@ class Party(Model):
         Check validity of SIREN
         '''
         for party in self.browse(ids):
-            if party.siren and not luhn.validate(party.siren):
-                return False
+            if party.siren:
+                if len(party.siren) != 9 or not luhn.validate(party.siren):
+                    return False
+            print party.addresses
         return True
 
 Party()
